data:extend(
{
  {
    type = "surface",
    name = "space-platform",
    icon = "__space-age__/graphics/icons/space-platform-surface.png",
    subgroup = "planets",
    order = "a[space-platform]",
    surface_properties =
    {
      gravity = 0,
      pressure = 0,
      ["magnetic-field"] = 0,
      ["day-night-cycle"] = 0
    }
  }
})
